@import url("cubicweb.css");

div.contentBox {
  background: whitesmoke;
  border-style: solid;
  border-width: thin;
}

li span.contentBox {
  background: whitesmoke;
  border-style: solid;
  border-width: thin;
}

li.invisible {
  /*   width: 40em; */
}

tr.souhait, tr.basse {
  background-color: floralwhite;
}

tr.minor {
  background-color: lavenderblush;
}

tr.normal, tr.moyen, tr.moyenne {
  background-color: pink;
}

tr.important, tr.haute, tr.critique {
  background-color: plum;
}

span.souhait, span.basse {
  background-color: floralwhite;
}

span.minor {
  background-color: lavenderblush;
}

span.normal, span.moyen, span.moyenne {
  background-color: pink;
}

span.important, span.haute, span.critique {
  background-color: plum;
}

table.stats {
  margin-left: auto;
  margin-right: auto;
}

td.alt0 {
  background-color: white;
}

td.alt1 {
  background-color: wheat;
}

tr.alt0 {
  background-color: white;
}

tr.alt1 {
  background-color: wheat;
}


td.souhait, td.basse {
  background-color: floralwhite;
}

td.normal, td.moyen, td.moyenne {
  background-color: pink;
}

td.important, td.haute, td.critique {
  background-color: plum;
}

span.storyTitle {
  font-weight: bold;

}
